#CS ===================================================================================================================================================================\\
	Name:				Page Menu Control UDC
	Author:				Antonio Do Rosario (Antop)
	Website:			www.antop.co.uk
	License:			Freeware
	AutoIt version:		3.3.6.1
	UDC version:		1.0
	
	Descrption: The page menu contains grouped lists of conceptually related pages (In AutoIt they don't have pages therfore it is windows that can be shown) or links.
	
	UDFs required:
					GUICtrlOnHover.au3
					Icons.au3
				
	Script Function:
					PageMenu_Create
					PageMenu_LoadInterfaceImages
					PageMenu_AddGroup
					PageMenu_GetHandleOfGroupButton
					PageMenu_GetHandleOfControlsWindow
					PageMenu_GetHandleOfControlsBK
					PageMenu_DeleteItem
					PageMenu_AddItem
					PageMenu_GetGroupItemCount
					PageMenu_GetGroupCount
					PageMenu_Destroy
					PageMenu_DeleteGroup
		
	History:
						v1.0
						* First public vesrion.
#CE ===================================================================================================================================================================//


#include-once
#include "Includes\GUICtrlOnHover.au3"
#include "Includes\Icons.au3"
Global $PageMenuUDF_FullData[1][11]	;Holds all the information about PageMenu Controls.
$PGMENPressedGroup = 0				; To make sure "PageMenuOnButtonUp" Func does not get called more then once.
$PGMENPressedLink = 0				; To make sure "PageMenuHyperLinkOnUp" Func does not get called more then once.


#cs Function ======================================================================================================\\
 Name...........:	PageMenu_GetHandleOfGroupButton
 Description....:	To get the handle of the Group Button so you can do something when it is clicked.
 Syntax.........:	PageMenu_GetHandleOfGroupButton($UDC_CtrlId, $iIndex)
 Parameters.....:	$UDC_CtrlId - Control ID as returned by PageMenu_Create.
					$iIndex - The index of the group. The first group is 1.

 Return values..:	Success - Returns The Handle of the Group Button.
					Failure - Returns -1.

 Author.........:	Antonio Do Rosario (Antop).
 Modified.......:	
 Remarks........:	
 Related........:	
 Link...........:	
 Example........:	
#ce ===============================================================================================================//
Func PageMenu_GetHandleOfGroupButton($UDC_CtrlId, $iIndex)
	Local $iRet = -1
	If $UDC_CtrlId > 0 And $UDC_CtrlId <= $PageMenuUDF_FullData[0][0] Then
		$Temp1 = StringSplit($PageMenuUDF_FullData[$UDC_CtrlId][3],"|")
		If $iIndex <= $Temp1[0] And $iIndex > 0 Then
			$Temp2 = StringSplit($Temp1[$iIndex],",",2)
			If $Temp2[0] <> 0 Then
				$iRet = Number($Temp2[0]+1)
			EndIf
		EndIf
	EndIf
	Return $iRet
EndFunc   ;==> PageMenu_GetHandleOfGroupButton


#cs Function ======================================================================================================\\
 Name...........:	PageMenu_GetHandleOfControlsWindow
 Description....:	To get the handle of the Parent window which the control has been displayed on.
 Syntax.........:	PageMenu_GetHandleOfControlsWindow($UDC_CtrlId)
 Parameters.....:	$UDC_CtrlId - Control ID as returned by PageMenu_Create.

 Return values..:	Success - Returns The Handle of the parent window.
					Failure - Returns -1.

 Author.........:	Antonio Do Rosario (Antop).
 Modified.......:	
 Remarks........:	
 Related........:	
 Link...........:	
 Example........:	
#ce ===============================================================================================================//
Func PageMenu_GetHandleOfControlsWindow($UDC_CtrlId)
	Local $iRet = -1
	If $UDC_CtrlId > 0 And $UDC_CtrlId <= $PageMenuUDF_FullData[0][0] Then
		$Temp1 = StringSplit($PageMenuUDF_FullData[$UDC_CtrlId][3],"|")
		If $Temp1[1] <> 0 Then
			$iRet = HWnd($Temp1[1])
		EndIf
	EndIf
	Return $iRet
EndFunc   ;==> PageMenu_GetHandleOfControlsWindow


#cs Function ======================================================================================================\\
 Name...........:	PageMenu_GetHandleOfControlsBK
 Description....:	To get the handle of the background image so you can change it at any later time.
 Syntax.........:	PageMenu_GetHandleOfControlsBK($UDC_CtrlId)
 Parameters.....:	$UDC_CtrlId - Control ID as returned by PageMenu_Create.

 Return values..:	Success - Returns the Handle of background image control.
					Failure - Returns -1.

 Author.........:	Antonio Do Rosario (Antop).
 Modified.......:	
 Remarks........:	
 Related........:	
 Link...........:	
 Example........:	
#ce ===============================================================================================================//
Func PageMenu_GetHandleOfControlsBK($UDC_CtrlId)
	Local $iRet = -1
	If $UDC_CtrlId > 0 And $UDC_CtrlId <= $PageMenuUDF_FullData[0][0] Then
		$Temp1 = StringSplit($PageMenuUDF_FullData[$UDC_CtrlId][3],"|")
		If $Temp1[0] <> 0 Then
			$iRet = Number($Temp1[0])
		EndIf
	EndIf
	Return $iRet
EndFunc   ;==> PageMenu_GetHandleOfControlsBK


#cs Function ======================================================================================================\\
 Name...........:	PageMenu_DeleteItem
 Description....:	Deletes a item from a group of the PageMenu Control.
 Syntax.........:	PageMenu_DeleteItem($UDC_CtrlId, $iGroupIndex, $iItemIndex)
 Parameters.....:	$UDC_CtrlId - Control ID as returned by PageMenu_Create.
					$iGroupIndex - The index of the group. The first group is 1.
					$iItemIndex - The index of the item. The first item is 1.

 Return values..:	Success - Returns 1 if the item has been deleted.
					Failure - Returns 0.

 Author.........:	Antonio Do Rosario (Antop).
 Modified.......:	
 Remarks........:	
 Related........:	
 Link...........:	
 Example........:	
#ce ===============================================================================================================//
Func PageMenu_DeleteItem($UDC_CtrlId, $iGroupIndex, $iItemIndex)
	Local $iRet = 0 ,$DeletedItemVer
	If $UDC_CtrlId > 0 And $UDC_CtrlId <= $PageMenuUDF_FullData[0][0] Then
		$Temp1 = StringSplit($PageMenuUDF_FullData[$UDC_CtrlId][3],"|")
		If $iGroupIndex <= $Temp1[0] And $iGroupIndex > 0 Then
			$Temp2 = StringSplit($Temp1[$iGroupIndex],",")
			If $iItemIndex <= $Temp2[2] And $iItemIndex > 0 Then
			
				$Temp3 = StringSplit($Temp2[5],"*")
				
				$CtrlPOS = ControlGetPos ( HWnd($PageMenuUDF_FullData[$UDC_CtrlId][1]), "", Number($Temp3[$Temp3[0]-1]))
				$CtrlPOS1 = ControlGetPos ( HWnd($PageMenuUDF_FullData[$UDC_CtrlId][1]), "", Number($Temp3[$Temp3[0]-1]+1))
				
				$CtrlPOS2 = ControlGetPos ( HWnd($PageMenuUDF_FullData[$UDC_CtrlId][1]), "", Number($Temp2[1]))
				$CtrlPOS3 = ControlGetPos ( HWnd($PageMenuUDF_FullData[$UDC_CtrlId][1]), "", Number($Temp2[1]+2))
				GUICtrlSetPos ( Number($Temp2[1]), $CtrlPOS2[0] ,$CtrlPOS2[1],$CtrlPOS2[2],$CtrlPOS2[3] -20)
				GUICtrlSetPos ( Number($Temp2[1]+2), $CtrlPOS3[0] ,$CtrlPOS3[1],$CtrlPOS3[2],$CtrlPOS3[3] -20)
				
				For $IZ = $iItemIndex To $Temp3[0]-1
					If $IZ = $iItemIndex Then
						_GUICtrl_OnHoverRegister(Number($Temp3[$IZ]), "")
						GUICtrlDelete(Number($Temp3[$IZ]))
						GUICtrlDelete(Number($Temp3[$IZ]+1))
						$DeletedItemVer = Number($Temp3[$IZ])
					Else
						$CtrlPosTemp = ControlGetPos(HWnd($PageMenuUDF_FullData[$UDC_CtrlId][1] ),"",Number($Temp3[$IZ]) )
						GUICtrlSetPos(Number($Temp3[$IZ]) ,$CtrlPosTemp[0] ,$CtrlPosTemp[1] -20)
						$CtrlPosTemp = ControlGetPos(HWnd($PageMenuUDF_FullData[$UDC_CtrlId][1] ),"",Number($Temp3[$IZ]+1) )
						GUICtrlSetPos(Number($Temp3[$IZ]+1) ,$CtrlPosTemp[0] ,$CtrlPosTemp[1] -20)
					EndIf
				Next
				
				;Moveing the bottom groups --------------------------------\\
				For $I = $iGroupIndex To $PageMenuUDF_FullData[$UDC_CtrlId][2] -1
					$TempX3 = StringSplit($Temp1[$I+1],",",2); Bottom Group Data
					
					$CtrlPosTemp1 = ControlGetPos(HWnd($PageMenuUDF_FullData[$UDC_CtrlId][1] ),"",Number($TempX3[0]) )
					$CtrlPosTemp2 = ControlGetPos(HWnd($PageMenuUDF_FullData[$UDC_CtrlId][1] ),"",Number($TempX3[0]+1) )
					$CtrlPosTemp3 = ControlGetPos(HWnd($PageMenuUDF_FullData[$UDC_CtrlId][1] ),"",Number($TempX3[0]+2) )
					$CtrlPosTemp4 = ControlGetPos(HWnd($PageMenuUDF_FullData[$UDC_CtrlId][1] ),"",Number($TempX3[0]+3) )
					
					GUICtrlSetPos(Number($TempX3[0]) ,$CtrlPosTemp1[0] ,$CtrlPosTemp1[1] -20 ); 	GroupLine
					GUICtrlSetPos(Number($TempX3[0]+1) ,$CtrlPosTemp2[0] ,$CtrlPosTemp2[1] -20 ); 	Button
					GUICtrlSetPos(Number($TempX3[0]+2) ,$CtrlPosTemp3[0] ,$CtrlPosTemp3[1] -20 ); 	Paper
					GUICtrlSetPos(Number($TempX3[0]+3) ,$CtrlPosTemp4[0] ,$CtrlPosTemp4[1] -20 ); 	Label
					
					$Temp4 = StringSplit($TempX3[4],"*")
					For $IZ = 1 To $Temp4[0]-1
						$CtrlPosTemp = ControlGetPos(HWnd($PageMenuUDF_FullData[$UDC_CtrlId][1] ),"",Number($Temp4[$IZ]) )
						GUICtrlSetPos(Number($Temp4[$IZ]) ,$CtrlPosTemp[0] ,$CtrlPosTemp[1] -20)
						$CtrlPosTemp = ControlGetPos(HWnd($PageMenuUDF_FullData[$UDC_CtrlId][1] ),"",Number($Temp4[$IZ]+1) )
						GUICtrlSetPos(Number($Temp4[$IZ]+1) ,$CtrlPosTemp[0] ,$CtrlPosTemp[1] -20)
					Next
				Next
				;Moveing the bottom groups --------------------------------//
				
				;Update the Data in the  main ver
				$ItemCollecter = ""
				For $IUPD = 1 To $Temp3[0]-1
					If $Temp3[$IUPD] <> $DeletedItemVer Then
						$ItemCollecter &= $Temp3[$IUPD] & "*"
					EndIf
				Next
				$NewData = $Temp2[1] &","& $Temp2[2]-1 &","& $Temp2[3] &","& (20*($Temp2[2]-1)+6)+28 &","& $ItemCollecter & "|"
				$ReplaceData = $Temp2[1] &","& $Temp2[2] &","& $Temp2[3] &","& $Temp2[4] &","& $Temp2[5] & "|"
				$PageMenuUDF_FullData[$UDC_CtrlId][3] = StringReplace($PageMenuUDF_FullData[$UDC_CtrlId][3],$ReplaceData,$NewData,0,1)
				
			EndIf
		EndIf
	EndIf
	Return $iRet
EndFunc   ;==> PageMenu_DeleteItem


#cs Function ======================================================================================================\\
 Name...........:	PageMenu_AddItem
 Description....:	Adds a item to a existing group of the PageMenu Control.
 Syntax.........:	PageMenu_AddItem($UDC_CtrlId, $iGroupIndex, $iItemName, $iItemVer, $iItemIconLocation)
 Parameters.....:	$UDC_CtrlId - Control ID as returned by PageMenu_Create.
					$iGroupIndex - The index of the group. The first group is 1.
					$iItemName - The name that should be given to the button of the group.
					$iItemIconLocation - The location of the icon to be used with the item.

 Return values..:	Success - Returns the Handle of the item that has been added.
					Failure - Returns 0.

 Author.........:	Antonio Do Rosario (Antop).
 Modified.......:	
 Remarks........:	
 Related........:	
 Link...........:	
 Example........:	
#ce ===============================================================================================================//
Func PageMenu_AddItem($UDC_CtrlId, $iGroupIndex, $iItemName, $iItemIconLocation)
	Local $iRet = 0
	If $UDC_CtrlId > 0 And $UDC_CtrlId <= $PageMenuUDF_FullData[0][0] Then
		$Temp1 = StringSplit($PageMenuUDF_FullData[$UDC_CtrlId][3],"|")
		If $iGroupIndex <= $Temp1[0] And $iGroupIndex > 0 Then
			$Temp2 = StringSplit($Temp1[$iGroupIndex],",")
			
			$Temp3 = StringSplit($Temp2[5],"*")
			$ItemCollecter = $Temp2[5]
			
			$CtrlPOS = ControlGetPos ( HWnd($PageMenuUDF_FullData[$UDC_CtrlId][1]), "", Number($Temp3[$Temp3[0]-1]))
			$CtrlPOS1 = ControlGetPos ( HWnd($PageMenuUDF_FullData[$UDC_CtrlId][1]), "", Number($Temp3[$Temp3[0]-1]+1))
			
			
			$PGM_GroupItem_ControlID = GUICtrlCreateLabel($iItemName, $CtrlPOS[0], ($CtrlPOS[1]+20), -1, 15);=====CTRL
			GUICtrlSetCursor($PGM_GroupItem_ControlID, 0)
			GUICtrlSetBkColor($PGM_GroupItem_ControlID, -2)
			GUICtrlSetResizing($PGM_GroupItem_ControlID, 0x0002 + 0x0020 + 0x0300)
			GUICtrlSetFont($PGM_GroupItem_ControlID, -1, -1)
			GUICtrlSetColor($PGM_GroupItem_ControlID, 0x0000FF)
			_GUICtrl_OnHoverRegister($PGM_GroupItem_ControlID, "PageMenuHyperLinkOnHover", "PageMenuHyperLinkOnHoverLeave", "PageMenuHyperLinkOnDown", "PageMenuHyperLinkOnUp", 0, 0)
			
			
			$UninstallSettingsIcon1 = GUICtrlCreatePic("" ,$CtrlPOS1[0] ,($CtrlPOS1[1]+20),16 ,16);=====CTRL
			_SetImage($UninstallSettingsIcon1, $iItemIconLocation)
			GUICtrlSetResizing($UninstallSettingsIcon1, 0x0002 + 0x0020 + 0x0300)
			
			$CtrlPOS2 = ControlGetPos ( HWnd($PageMenuUDF_FullData[$UDC_CtrlId][1]), "", Number($Temp2[1]))
			$CtrlPOS3 = ControlGetPos ( HWnd($PageMenuUDF_FullData[$UDC_CtrlId][1]), "", Number($Temp2[1]+2))
			GUICtrlSetPos ( Number($Temp2[1]), $CtrlPOS2[0] ,$CtrlPOS2[1],$CtrlPOS2[2],$CtrlPOS2[3]+20)
			GUICtrlSetPos ( Number($Temp2[1]+2), $CtrlPOS3[0] ,$CtrlPOS3[1],$CtrlPOS3[2],$CtrlPOS3[3]+20)
			
			;Moveing the bottom groups
			For $I = $iGroupIndex To $PageMenuUDF_FullData[$UDC_CtrlId][2] -1
				$TempX3 = StringSplit($Temp1[$I+1],",",2); Bottom Group Data
			
				$CtrlPosTemp1 = ControlGetPos(HWnd($PageMenuUDF_FullData[$UDC_CtrlId][1] ),"",Number($TempX3[0]) )
				$CtrlPosTemp2 = ControlGetPos(HWnd($PageMenuUDF_FullData[$UDC_CtrlId][1] ),"",Number($TempX3[0]+1) )
				$CtrlPosTemp3 = ControlGetPos(HWnd($PageMenuUDF_FullData[$UDC_CtrlId][1] ),"",Number($TempX3[0]+2) )
				$CtrlPosTemp4 = ControlGetPos(HWnd($PageMenuUDF_FullData[$UDC_CtrlId][1] ),"",Number($TempX3[0]+3) )
			
				GUICtrlSetPos(Number($TempX3[0]) ,$CtrlPosTemp1[0] ,$CtrlPosTemp1[1] +20 ); 	GroupLine
				GUICtrlSetPos(Number($TempX3[0]+1) ,$CtrlPosTemp2[0] ,$CtrlPosTemp2[1] +20 ); 	Button
				GUICtrlSetPos(Number($TempX3[0]+2) ,$CtrlPosTemp3[0] ,$CtrlPosTemp3[1] +20 ); 	Paper
				GUICtrlSetPos(Number($TempX3[0]+3) ,$CtrlPosTemp4[0] ,$CtrlPosTemp4[1] +20 ); 	Label

				$Temp4 = StringSplit($TempX3[4],"*")
				For $IZ = 1 To $Temp4[0]-1
					$CtrlPosTemp = ControlGetPos(HWnd($PageMenuUDF_FullData[$UDC_CtrlId][1] ),"",Number($Temp4[$IZ]) )
					GUICtrlSetPos(Number($Temp4[$IZ]) ,$CtrlPosTemp[0] ,$CtrlPosTemp[1] +20)
					$CtrlPosTemp = ControlGetPos(HWnd($PageMenuUDF_FullData[$UDC_CtrlId][1] ),"",Number($Temp4[$IZ]+1) )
					GUICtrlSetPos(Number($Temp4[$IZ]+1) ,$CtrlPosTemp[0] ,$CtrlPosTemp[1] +20)
				Next
			Next
			
			;Update the Data in the  main ver
			$ItemCollecter &= $PGM_GroupItem_ControlID &"*"
			$NewData = $Temp2[1] &","& $Temp2[2]+1 &","& $Temp2[3] &","& (20*($Temp2[2]+1)+6)+28 &","& $ItemCollecter & "|"
			$ReplaceData = $Temp2[1] &","& $Temp2[2] &","& $Temp2[3] &","& $Temp2[4] &","& $Temp2[5] & "|"
			$PageMenuUDF_FullData[$UDC_CtrlId][3] = StringReplace($PageMenuUDF_FullData[$UDC_CtrlId][3],$ReplaceData,$NewData,0,1)
			$iRet = $PGM_GroupItem_ControlID
		EndIf
	EndIf
	Return $iRet
EndFunc   ;==> PageMenu_AddItem


#cs Function ======================================================================================================\\
 Name...........:	PageMenu_GetGroupItemCount
 Description....:	To get the number of items within a group.
 Syntax.........:	PageMenu_GetGroupItemCount($UDC_CtrlId, $iIndex)
 Parameters.....:	$UDC_CtrlId - Control ID as returned by PageMenu_Create.
					$iIndex - The index of the group. The first group is 1.

 Return values..:	Success - Returns the count of items within a group.
					Failure - Returns -1.

 Author.........:	Antonio Do Rosario (Antop).
 Modified.......:	
 Remarks........:	
 Related........:	
 Link...........:	
 Example........:	
#ce ===============================================================================================================//
Func PageMenu_GetGroupItemCount($UDC_CtrlId, $iIndex)
	Local $iRet = -1
	If $UDC_CtrlId > 0 And $UDC_CtrlId <= $PageMenuUDF_FullData[0][0] Then
		$Temp1 = StringSplit($PageMenuUDF_FullData[$UDC_CtrlId][3],"|")
		If $iIndex <= $Temp1[0] And $iIndex > 0 Then
			$Temp2 = StringSplit($Temp1[$iIndex],",",2)
			If $Temp2[1] <> 0 Then
				$iRet = $Temp2[1]
			EndIf
		EndIf
	EndIf
	Return $iRet
EndFunc   ;==> PageMenu_GetGroupItemCount


#cs Function ======================================================================================================\\
 Name...........:	PageMenu_GetGroupCount
 Description....:	To get the number of groups within a control.
 Syntax.........:	PageMenu_GetGroupCount($UDC_CtrlId)
 Parameters.....:	$UDC_CtrlId - Control ID as returned by PageMenu_Create.

 Return values..:	Success - Returns the count of groups.
					Failure - Returns -1.

 Author.........:	Antonio Do Rosario (Antop).
 Modified.......:	
 Remarks........:	
 Related........:	
 Link...........:	
 Example........:	
#ce ===============================================================================================================//
Func PageMenu_GetGroupCount($UDC_CtrlId)
	Local $iRet = -1
	If $UDC_CtrlId > 0 And $UDC_CtrlId <= $PageMenuUDF_FullData[0][0] Then
		$iRet = $PageMenuUDF_FullData[$UDC_CtrlId][2]
	EndIf
	Return $iRet
EndFunc   ;==> PageMenu_GetGroupCount


#cs Function ======================================================================================================\\
 Name...........:	PageMenu_LoadInterfaceImages
 Description....:	Loads the images which are required by the PageMenu Control. This function must be called after "PageMenu_Create" Function.
 Syntax.........:	PageMenu_LoadInterfaceImages($UDC_CtrlId, $PGMImages1, $PGMImages2, $PGMImages3, $PGMImages4, $PGMImages5, $PGMImages6, $PGMImages7)
 Parameters.....:	$UDC_CtrlId - Control ID as returned by PageMenu_Create.
					$PGMImages1 - (Up Button) Image location.
					$PGMImages2 - (Up Button lighted) Image location.
					$PGMImages3 - (Up Button Pressed) Image location.
					$PGMImages4 - (Down Button) Image location.
					$PGMImages5 - (Down Button lighted) Image location.
					$PGMImages6 - (Down Button Pressed) Image location.
					$PGMImages7 - Image which goes below the button (Paper) Image location.

 Return values..:	Success - Returns 1.
					Failure - Returns 0.

 Author.........:	Antonio Do Rosario (Antop).
 Modified.......:	
 Remarks........:	
 Related........:	
 Link...........:	
 Example........:	
#ce ===============================================================================================================//
Func PageMenu_LoadInterfaceImages($UDC_CtrlId, $PGMImages1, $PGMImages2, $PGMImages3, $PGMImages4, $PGMImages5, $PGMImages6, $PGMImages7)
	Local $iRet = 0, $TempVer
	If $UDC_CtrlId > 0 And $UDC_CtrlId <= $PageMenuUDF_FullData[0][0] Then
		; Location of the Images
		$PageMenuUDF_FullData[$UDC_CtrlId][4] = $PGMImages1  ;Up Button
		$PageMenuUDF_FullData[$UDC_CtrlId][5] = $PGMImages2  ;Up Button lighted
		$PageMenuUDF_FullData[$UDC_CtrlId][6] = $PGMImages3  ;Up Button Pressed
		$PageMenuUDF_FullData[$UDC_CtrlId][7] = $PGMImages4  ;Down Button
		$PageMenuUDF_FullData[$UDC_CtrlId][8] = $PGMImages5  ;Down Button lighted
		$PageMenuUDF_FullData[$UDC_CtrlId][9] = $PGMImages6  ;Down Button Pressed
		$PageMenuUDF_FullData[$UDC_CtrlId][10] = $PGMImages7 ;Image which goes below the button (Paper)
		$iRet = 1
	EndIf
	Return $iRet
EndFunc   ;==> PageMenu_LoadInterfaceImages


#cs Function ======================================================================================================\\
 Name...........:	PageMenu_Create
 Description....:	Creates a PageMenu control.
 Syntax.........:	PageMenu_Create($hWnd ,$iLeft ,$iTop ,$iWidth ,$iHeight ,$iBKImage, $DockCtrlBottom = 0 )
 Parameters.....:	$hWnd - Handle to parent or owner window.
					$iLeft         - The left side of the control. If -1 is used then left will be computed according to GUICoordMode.
					$iTop          - The top of the control. If -1 is used then top will be computed according to GUICoordMode. 
					$iWidth        - The width of the control (default text autofit in width). 
					$iHeight       - The height of the control (default text autofit in height). 
					$iBKImage - The location of the background Image.
					$DockCtrlBottom - [Optional] if 1 then the background image will be docked to the bottom of the window.
					
 Return values..:	Success - Returns Handle to the control.
					Failure - Returns -1.
					
 Author.........:	Antonio Do Rosario (Antop).
 Modified.......:	
 Remarks........:	
 Related........:	
 Link...........:	
 Example........:	
#ce ===============================================================================================================//
Func PageMenu_Create($hWnd ,$iLeft ,$iTop ,$iWidth ,$iHeight ,$iBKImage, $DockCtrlBottom = 0 )
	Local $iRet = -1, $TempVer
	If IsHWnd($hWnd ) Then
		If $PageMenuUDF_FullData[0][1] <> "" Then
			$TempDstPMs = StringSplit($PageMenuUDF_FullData[0][1], "^")
			If $TempDstPMs[0] <> 0 And $TempDstPMs[0] <> 1 Then; Recycling old controls handle
				$TempVer = $PageMenuUDF_FullData[0][0]
				$PageMenuUDF_FullData[0][0] = $TempDstPMs[$TempDstPMs[0]-1]
				$PageMenuUDF_FullData[0][1] = StringTrimRight($PageMenuUDF_FullData[0][1],StringLen($TempDstPMs[$TempDstPMs[0]-1]&"^"))
			EndIf
		Else
			$PageMenuUDF_FullData[0][0] += 1
			ReDim $PageMenuUDF_FullData[$PageMenuUDF_FullData[0][0]+1][11]
		EndIf
		
		If $DockCtrlBottom = 1 Then
			$WinDPOS = WinGetPos($hWnd)
			$PageMenuUDFBKImage = GUICtrlCreatePic ($iBKImage ,$iLeft ,$iTop ,$iWidth , $WinDPOS[3]- $iTop)
			GUICtrlSetResizing( $PageMenuUDFBKImage, 0x0040+0x0002+0x0220+0x0100)
		Else
			$PageMenuUDFBKImage = GUICtrlCreatePic ($iBKImage ,$iLeft ,$iTop ,$iWidth , $iHeight)
			GUICtrlSetResizing( $PageMenuUDFBKImage, 0x0002 + 0x0020 + 0x0300)
		EndIf
		GUICtrlSetState($PageMenuUDFBKImage , 128)
	
		$PageMenuUDF_FullData[$PageMenuUDF_FullData[0][0]][0] = $PageMenuUDFBKImage		;Control ID (BK Image)
		$PageMenuUDF_FullData[$PageMenuUDF_FullData[0][0]][1] = $hWnd					;Parent GUI
		$PageMenuUDF_FullData[$PageMenuUDF_FullData[0][0]][2] = 0						;Num of Groups
		$PageMenuUDF_FullData[$PageMenuUDF_FullData[0][0]][3] = 0						;DATA E.g  id1,NumITs|
		; Image:
		$PageMenuUDF_FullData[$PageMenuUDF_FullData[0][0]][4] = 0  ;Up Button
		$PageMenuUDF_FullData[$PageMenuUDF_FullData[0][0]][5] = 0  ;Up Button Highlighted
		$PageMenuUDF_FullData[$PageMenuUDF_FullData[0][0]][6] = 0  ;Up Button Pressed
		$PageMenuUDF_FullData[$PageMenuUDF_FullData[0][0]][7] = 0  ;Down Button
		$PageMenuUDF_FullData[$PageMenuUDF_FullData[0][0]][8] = 0  ;Down Button Highlighted
		$PageMenuUDF_FullData[$PageMenuUDF_FullData[0][0]][9] = 0  ;Down Button Pressed
		$PageMenuUDF_FullData[$PageMenuUDF_FullData[0][0]][10] = 0 ;Image which goes below the button (Paper)
		
		If $TempVer <> "" Then
			$iRet = $PageMenuUDF_FullData[0][0]
			$PageMenuUDF_FullData[0][0] = $TempVer
		Else
			$iRet = $PageMenuUDF_FullData[0][0]
		EndIf
	EndIf
	Return $iRet
EndFunc   ;==> PageMenu_Create


#cs Function ======================================================================================================\\
 Name...........:	PageMenu_Destroy
 Description....:	Deletes PageMenu Control.
 Syntax.........:	PageMenu_Destroy($UDC_CtrlId)
 Parameters.....:	$UDC_CtrlId - Control ID as returned by PageMenu_Create.

 Return values..:	Success - Returns 1 if control has been deleted.
					Failure - Returns 0.

 Author.........:	Antonio Do Rosario (Antop).
 Modified.......:	
 Remarks........:	
 Related........:	
 Link...........:	
 Example........:	
#ce ===============================================================================================================//
Func PageMenu_Destroy($UDC_CtrlId)
	Local $iRet = 0	
	If $UDC_CtrlId > 0 And $UDC_CtrlId <= $PageMenuUDF_FullData[0][0] Then
		If $PageMenuUDF_FullData[$UDC_CtrlId][3] <> 0 And $PageMenuUDF_FullData[$UDC_CtrlId][0] <> 0 Then
			$Temp1 = StringSplit($PageMenuUDF_FullData[$UDC_CtrlId][3],"|")
		
			GUISetState(@SW_DISABLE,HWnd ($PageMenuUDF_FullData[$UDC_CtrlId][1]))
			Sleep(20)
			For $I = 1 To $Temp1[0]-1
				$Temp2 = StringSplit($Temp1[$I],",",2)
				GUICtrlDelete($Temp2[0])
				_GUICtrl_OnHoverRegister(Number($Temp2[0]+1), "")
				GUICtrlDelete($Temp2[0]+1)
				GUICtrlDelete($Temp2[0]+2)
				GUICtrlDelete($Temp2[0]+3)
				$Temp3 = StringSplit($Temp2[4],"*",2)
				For $IZ = 0 To $Temp2[1]-1
					_GUICtrl_OnHoverRegister(Number($Temp3[$IZ]), "")
					GUICtrlDelete(Number($Temp3[$IZ]))
					GUICtrlDelete(Number($Temp3[$IZ]+1))
				Next
			Next
			GUICtrlDelete($PageMenuUDF_FullData[$UDC_CtrlId][0])
			GUISetState(@SW_ENABLE,HWnd ($PageMenuUDF_FullData[$UDC_CtrlId][1]))
		
			For $iG = 0 To 10
				$PageMenuUDF_FullData[$UDC_CtrlId][$iG] = 0
			Next
			$PageMenuUDF_FullData[0][1] &= $UDC_CtrlId &"^"
			$iRet = 1
		EndIf
	EndIf
	Return $iRet
EndFunc   ;==> PageMenu_Destroy


#cs Function ======================================================================================================\\
 Name...........:	PageMenu_DeleteGroup
 Description....:	Deletes PageMenu Group.
 Syntax.........:	PageMenu_DeleteGroup($UDC_CtrlId, $iIndex)
 Parameters.....:	$UDC_CtrlId - Control ID as returned by PageMenu_Create.
					$iIndex - Group index Number. First group is 1.
					
 Return values..:	Success - Returns 1 if Group has been deleted.
					Failure - Returns 0.
					
 Author.........:	Antonio Do Rosario (Antop).
 Modified.......:	
 Remarks........:	
 Related........:	
 Link...........:	
 Example........:	
#ce ===============================================================================================================//
Func PageMenu_DeleteGroup($UDC_CtrlId, $iIndex)
	Local $iRet = 0	

	If $UDC_CtrlId > 0 And $UDC_CtrlId <= $PageMenuUDF_FullData[0][0] Then
		$Temp1 = StringSplit($PageMenuUDF_FullData[$UDC_CtrlId][3],"|")
		If $iIndex <= $Temp1[0] And $iIndex > 0 Then
			$Temp2 = StringSplit($Temp1[$iIndex],",",2)
			GUICtrlDelete($Temp2[0])
			_GUICtrl_OnHoverRegister(Number($Temp2[0]+1), "")
			GUICtrlDelete($Temp2[0]+1)
			GUICtrlDelete($Temp2[0]+2)
			GUICtrlDelete($Temp2[0]+3)
			$Temp3 = StringSplit($Temp2[4],"*",2)
			For $IZ = 0 To $Temp2[1]-1
				_GUICtrl_OnHoverRegister(Number($Temp3[$IZ]), "")
				GUICtrlDelete(Number($Temp3[$IZ]))
				GUICtrlDelete(Number($Temp3[$IZ]+1))
			Next
	
			;Update the Data in the  main ver
			$StartUpdateingInfo = 0
			$ReCollect = ""
			For $IUPD = 1 To $Temp1[0]-1
				If $Temp1[$IUPD] = $Temp1[$iIndex] Then
					$DHeight = $Temp2[3]
					$StartUpdateingInfo = 1
				Else
					$ReCollect &= $Temp1[$IUPD] & "|"
					If $StartUpdateingInfo = 1 Then
						$Temp2 = StringSplit($Temp1[$IUPD],",",2)
						GUICtrlSetStyle ( Number($Temp2[0]), 0x0000 )
						GUICtrlSetData(Number($Temp2[0]),$UDC_CtrlId &"|"& $IUPD-1)
						GUICtrlSetStyle ( Number($Temp2[0]), 0x05 )
					EndIf
				EndIf
			Next
			$PageMenuUDF_FullData[$UDC_CtrlId][3] = $ReCollect
			$PageMenuUDF_FullData[$UDC_CtrlId][2] -= 1
		
			$Temp1 = StringSplit($PageMenuUDF_FullData[$UDC_CtrlId][3],"|")
			;Moveing the bottom groups
			For $I = $iIndex To $PageMenuUDF_FullData[$UDC_CtrlId][2]
				$TempX3 = StringSplit($Temp1[$I],",",2); Bottom Group Data
				$CtrlPosTemp1 = ControlGetPos(HWnd($PageMenuUDF_FullData[$UDC_CtrlId][1] ),"",Number($TempX3[0]) )
				$CtrlPosTemp2 = ControlGetPos(HWnd($PageMenuUDF_FullData[$UDC_CtrlId][1] ),"",Number($TempX3[0]+1) )
				$CtrlPosTemp3 = ControlGetPos(HWnd($PageMenuUDF_FullData[$UDC_CtrlId][1] ),"",Number($TempX3[0]+2) )
				$CtrlPosTemp4 = ControlGetPos(HWnd($PageMenuUDF_FullData[$UDC_CtrlId][1] ),"",Number($TempX3[0]+3) )
				
				GUICtrlSetPos(Number($TempX3[0]) ,$CtrlPosTemp1[0] ,$CtrlPosTemp1[1] -$DHeight-8 ); 	GroupLine
				GUICtrlSetPos(Number($TempX3[0]+1) ,$CtrlPosTemp2[0] ,$CtrlPosTemp2[1] -$DHeight-8 ); 	Button
				GUICtrlSetPos(Number($TempX3[0]+2) ,$CtrlPosTemp3[0] ,$CtrlPosTemp3[1] -$DHeight-8 ); 	Paper
				GUICtrlSetPos(Number($TempX3[0]+3) ,$CtrlPosTemp4[0] ,$CtrlPosTemp4[1] -$DHeight-8 ); 	Label
		
				$Temp4 = StringSplit($TempX3[4],"*")
				For $IZ = 1 To $Temp4[0]-1
					$CtrlPosTemp = ControlGetPos(HWnd($PageMenuUDF_FullData[$UDC_CtrlId][1] ),"",Number($Temp4[$IZ]) )
					GUICtrlSetPos(Number($Temp4[$IZ]) ,$CtrlPosTemp[0] ,$CtrlPosTemp[1] -$DHeight-8 )
					$CtrlPosTemp = ControlGetPos(HWnd($PageMenuUDF_FullData[$UDC_CtrlId][1] ),"",Number($Temp4[$IZ]+1) )
					GUICtrlSetPos(Number($Temp4[$IZ]+1) ,$CtrlPosTemp[0] ,$CtrlPosTemp[1] -$DHeight-8 )
				Next
			Next
			$iRet = 1
		EndIf
	EndIf
	Return $iRet
EndFunc   ;==> PageMenu_DeleteGroup


#cs Function ======================================================================================================\\
 Name...........:	PageMenu_AddGroup
 Description....:	Adds a Group at the bottom of an existing PageMenu Group.
 Syntax.........:	PageMenu_AddGroup($UDC_CtrlId, $avArray)
 Parameters.....:	$UDC_CtrlId - Control ID as returned by PageMenu_Create.
					$avArray - Array containing the information of the group. An E.g. is below this line.
							   Local $avArray[3] = ["Name of Group", "Item1 Name|"Item1 Icon Location", "Item2 Name|"Item2 Icon Location"]
					
 Return values..:	Success - Returns an array where $ReturnArray[0] has the count of the items and Handles are given in $ReturnArray[1] and so on.
					Failure - Returns an array where $ReturnArray[0] will be 0.
					
 Author.........:	Antonio Do Rosario (Antop).
 Modified.......:	
 Remarks........:	
 Related........:	
 Link...........:	
 Example........:	
#ce ===============================================================================================================//
Func PageMenu_AddGroup($UDC_CtrlId, $avArray )
	Local $iRet[1], $TempArray[UBound($avArray)]
	$iRet[0] = 0
	If $UDC_CtrlId > 0 And $UDC_CtrlId <= $PageMenuUDF_FullData[0][0] Then
		If IsArray($avArray) Then
			$Temp1 = StringSplit($PageMenuUDF_FullData[$UDC_CtrlId][3],"|")
			$NumberOfGps = $PageMenuUDF_FullData[$UDC_CtrlId][2]
			$ParentGUI = HWnd ($PageMenuUDF_FullData[$UDC_CtrlId][1])
			$Temp2 = StringSplit($Temp1[$Temp1[0]-1],",")
	
			$CtrlPOS = ControlGetPos ( $ParentGUI, "", $PageMenuUDF_FullData[$UDC_CtrlId][0] )
			If $NumberOfGps <> 0 Then
				$CtrlPOS[1] = $Temp2[4]+$Temp2[3]
			EndIf
			$SizeOfPaper = 20 * (UBound($avArray)-1)+6
		
			;----------------GroupLine
			Local $GroupLine = GUICtrlCreateLabel($UDC_CtrlId&"|"&$NumberOfGps+1 ,$CtrlPOS[0]+7 ,$CtrlPOS[1]+7 ,$CtrlPOS[2]-14 ,$SizeOfPaper+30 ,0x05 )
			GUICtrlSetBkColor($GroupLine, 0xA0A0A0)
			GUICtrlSetResizing($GroupLine, 0x0002 + 0x0020 + 0x0300)
			GUICtrlSetState($GroupLine, 128)
		
			;----------------Button
			Local $GroupButton = GUICtrlCreatePic ($PageMenuUDF_FullData[$UDC_CtrlId][4],$CtrlPOS[0]+8 ,$CtrlPOS[1]+8 ,$CtrlPOS[2]-16 , 28)
			GUICtrlSetResizing($GroupButton, 0x0002 + 0x0020 + 0x0300)
			GUICtrlSetCursor($GroupButton, 0)
			_GUICtrl_OnHoverRegister($GroupButton, "PageMenuOnButtonHover", "PageMenuOnButtonHoverLeave", "PageMenuOnButtonDown", "PageMenuOnButtonUp", 0, 0)
			
			;----------------Paper
			Local $GroupPaper  = GUICtrlCreatePic ($PageMenuUDF_FullData[$UDC_CtrlId][10],$CtrlPOS[0]+8 ,$CtrlPOS[1]+8+28 ,$CtrlPOS[2]-16 ,$SizeOfPaper )
			GUICtrlSetResizing($GroupPaper, 0x0002 + 0x0020 + 0x0300)
			GUICtrlSetState($GroupPaper, 128)
	
			;----------------Label
			Local $GroupLabel = GUICtrlCreateLabel($avArray[0] ,$CtrlPOS[0]+8 ,$CtrlPOS[1]+8+5 ,$CtrlPOS[2]-16 ,15 ,0x1)
			GUICtrlSetResizing($GroupLabel, 0x0002 + 0x0020 + 0x0300)
			GUICtrlSetBkColor($GroupLabel, -2)
			GUICtrlSetCursor($GroupLabel, 0)
		
			$PageMenuUDF_FullData[$UDC_CtrlId][2] += 1
			$ItemCollecter  = ""
			
			$TempArray[0] = UBound($avArray)-1
			$I1 = 5
			For $I = 1 To UBound($avArray)-1
				$ItemDataSplit = StringSplit($avArray[$I], "|")
		
				If $ItemDataSplit[0] = 2 Then
					$PGM_GroupItem_ControlID = GUICtrlCreateLabel($ItemDataSplit[1], $CtrlPOS[0]+8+32, ($CtrlPOS[1]+8+28)+$I1, -1, 15)
					GUICtrlSetCursor($PGM_GroupItem_ControlID, 0)
					GUICtrlSetBkColor($PGM_GroupItem_ControlID, -2)
					GUICtrlSetResizing($PGM_GroupItem_ControlID, 0x0002 + 0x0020 + 0x0300)
					GUICtrlSetFont($PGM_GroupItem_ControlID, -1, -1)
					GUICtrlSetColor($PGM_GroupItem_ControlID, 0x0000FF)
					_GUICtrl_OnHoverRegister($PGM_GroupItem_ControlID, "PageMenuHyperLinkOnHover", "PageMenuHyperLinkOnHoverLeave", "PageMenuHyperLinkOnDown", "PageMenuHyperLinkOnUp", 0, 0)
					$ItemCollecter &= $PGM_GroupItem_ControlID &"*"
			
					$PGM_GroupItemIcon_ControlID = GUICtrlCreatePic("" ,$CtrlPOS[0]+8+10 ,($CtrlPOS[1]+7+28)+$I1 ,16 ,16)
					_SetImage($PGM_GroupItemIcon_ControlID, $ItemDataSplit[2])
					GUICtrlSetResizing($PGM_GroupItemIcon_ControlID, 0x0002 + 0x0020 + 0x0300)
					$I1 = $I1+20
					$TempArray[$I] = $PGM_GroupItem_ControlID
				EndIf
			Next
	
			If $NumberOfGps = 0 Then
				$PageMenuUDF_FullData[$UDC_CtrlId][3] = $GroupLine &","& (UBound($avArray)-1) &","& $CtrlPOS[1]+8 &","& $SizeOfPaper+28 &","& $ItemCollecter & "|"
			Else
				$PageMenuUDF_FullData[$UDC_CtrlId][3] &= $GroupLine &","& (UBound($avArray)-1) &","& $CtrlPOS[1]+8 &","& $SizeOfPaper+28 &","& $ItemCollecter & "|"
			EndIf
			$iRet = $TempArray
		EndIf
	EndIf
	Return $iRet
EndFunc   ;==> PageMenu_AddGroup




; #FUNCTIONS FOR INTERNAL USE# ==================================================================================================

Func PageMenuHyperLinkOnHover($CtrlIdOfOn)
	GUICtrlSetFont($CtrlIdOfOn, Default, Default, 4)
EndFunc   ;==> PageMenuHyperLinkOnHover

Func PageMenuHyperLinkOnHoverLeave($CtrlIdOfOn)
	GUICtrlSetColor($CtrlIdOfOn, 0x0000FF)
	GUICtrlSetFont($CtrlIdOfOn, Default, Default, 0)
EndFunc   ;==> PageMenuHyperLinkOnHoverLeave

Func PageMenuHyperLinkOnUp($CtrlIdOfOn)
	If $PGMENPressedLink = 1 Then
		$PGMENPressedLink = 0;Making sure this Func does not get called more then once
		GUICtrlSetColor($CtrlIdOfOn, 0x0000FF)
	GUICtrlSetFont($CtrlIdOfOn, Default, Default, 4)
	EndIf
EndFunc   ;==> PageMenuHyperLinkOnUp

Func PageMenuHyperLinkOnDown($CtrlIdOfOn)
	GUICtrlSetColor($CtrlIdOfOn, 0x000077)
	GUICtrlSetFont($CtrlIdOfOn, Default, Default, 4)
	$PGMENPressedLink = 1
EndFunc   ;==> PageMenuHyperLinkOnDown


Func PageMenuOnButtonHover($CtrlIdOfOn)
	$Temp1 = StringSplit(GUICtrlRead($CtrlIdOfOn-1),"|")
	$Temp2 = ControlGetPos(HWnd($PageMenuUDF_FullData[$Temp1[1]][1]),"",Number($CtrlIdOfOn+1))
	If $Temp2[3] = 1 Then
		GUICtrlSetImage ( $CtrlIdOfOn, $PageMenuUDF_FullData[$Temp1[1]][8])
	Else
		GUICtrlSetImage ( $CtrlIdOfOn, $PageMenuUDF_FullData[$Temp1[1]][5])
	EndIf
EndFunc   ;==> PageMenuOnButtonHover


Func PageMenuOnButtonHoverLeave($CtrlIdOfOn)
	$Temp1 = StringSplit(GUICtrlRead($CtrlIdOfOn-1),"|")
	$Temp2 = ControlGetPos(HWnd($PageMenuUDF_FullData[$Temp1[1]][1]),"",Number($CtrlIdOfOn+1))
	If $Temp2[3] = 1 Then
		GUICtrlSetImage ( $CtrlIdOfOn, $PageMenuUDF_FullData[$Temp1[1]][7])
	Else
		GUICtrlSetImage ( $CtrlIdOfOn, $PageMenuUDF_FullData[$Temp1[1]][4])
	EndIf
EndFunc   ;==> PageMenuOnButtonHoverLeave


Func PageMenuOnButtonUp($CtrlIdOfOn)
	If $PGMENPressedGroup = 1 Then
		$PGMENPressedGroup = 0;Making sure this Func does not get called more then once
		$Temp3 = StringSplit(GUICtrlRead($CtrlIdOfOn-1),"|"); Spliting data from the label
		$Temp1 = StringSplit($PageMenuUDF_FullData[$Temp3[1]][3],"|");  Spliting groups
		$Temp2 = StringSplit($Temp1[$Temp3[2]],",",2);spliting the Clicked group data
		$ParentGUI = $PageMenuUDF_FullData[$Temp3[1]][1]
		$NumOfGps = $PageMenuUDF_FullData[$Temp3[1]][2]
	
		$CtrlPosTempMM = ControlGetPos(HWnd($ParentGUI ),"",$CtrlIdOfOn+1 ); POS of the clicked Group
		If $CtrlPosTempMM[3] = 1 Then
			
			;Showing the clicked Group
			$Temp4 = StringSplit($Temp2[4],"*")
			For $IZ = 1 To $Temp4[0]-1
				GUICtrlSetState(Number($Temp4[$IZ]),16)
				GUICtrlSetState(Number($Temp4[$IZ]+1),16)
			Next
			GUICtrlSetPos ( $CtrlIdOfOn+1, $CtrlPosTempMM[0] ,$CtrlPosTempMM[1],$CtrlPosTempMM[2],$Temp2[3]-28)
			GUICtrlSetPos ( $CtrlIdOfOn-1, $CtrlPosTempMM[0]-1 ,$CtrlPosTempMM[1]-29,$CtrlPosTempMM[2]+2,$Temp2[3]+2)
			;--------------------------------------------------------------------
			
			;Moveing the bottom groups
			For $I = $Temp3[2] To $NumOfGps -1
				$TempX3 = StringSplit($Temp1[$I+1],",",2); Bottom Group Data
			
				$CtrlPosTemp1 = ControlGetPos(HWnd($ParentGUI ),"",Number($TempX3[0]) )
				$CtrlPosTemp2 = ControlGetPos(HWnd($ParentGUI ),"",Number($TempX3[0]+1) )
				$CtrlPosTemp3 = ControlGetPos(HWnd($ParentGUI ),"",Number($TempX3[0]+2) )
				$CtrlPosTemp4 = ControlGetPos(HWnd($ParentGUI ),"",Number($TempX3[0]+3) )
			
				GUICtrlSetPos(Number($TempX3[0]) ,$CtrlPosTemp1[0] ,$CtrlPosTemp1[1] + ($Temp2[3]-28)); 	GroupLine
				GUICtrlSetPos(Number($TempX3[0]+1) ,$CtrlPosTemp2[0] ,$CtrlPosTemp2[1] + ($Temp2[3]-28)); 	Button
				GUICtrlSetPos(Number($TempX3[0]+2) ,$CtrlPosTemp3[0] ,$CtrlPosTemp3[1] + ($Temp2[3]-28)); 	Paper
				GUICtrlSetPos(Number($TempX3[0]+3) ,$CtrlPosTemp4[0] ,$CtrlPosTemp4[1] + ($Temp2[3]-28)); 	Label

				$Temp4 = StringSplit($TempX3[4],"*")
				For $IZ = 1 To $Temp4[0]-1
					$CtrlPosTemp = ControlGetPos(HWnd($ParentGUI ),"",Number($Temp4[$IZ]) )
					GUICtrlSetPos(Number($Temp4[$IZ]) ,$CtrlPosTemp[0] ,$CtrlPosTemp[1] + ($Temp2[3]-28))
					$CtrlPosTemp = ControlGetPos(HWnd($ParentGUI ),"",Number($Temp4[$IZ]+1) )
					GUICtrlSetPos(Number($Temp4[$IZ]+1) ,$CtrlPosTemp[0] ,$CtrlPosTemp[1] + ($Temp2[3]-28))
				Next
			Next
			
		Else
			;Hideing the clicked Group
			$Temp4 = StringSplit($Temp2[4],"*")
			For $IZ = 1 To $Temp4[0]-1
				GUICtrlSetState(Number($Temp4[$IZ]),32)
				GUICtrlSetState(Number($Temp4[$IZ]+1),32)
			Next
			
			GUICtrlSetPos ( $CtrlIdOfOn+1, $CtrlPosTempMM[0] ,$CtrlPosTempMM[1],$CtrlPosTempMM[2],1)
			GUICtrlSetPos ( $CtrlIdOfOn-1, $CtrlPosTempMM[0]-1 ,$CtrlPosTempMM[1]-29,$CtrlPosTempMM[2]+2,31)
			;--------------------------------------------------------------------
			
			;Moveing the bottom groups
			For $I = $Temp3[2] To $NumOfGps -1
				$TempX3 = StringSplit($Temp1[$I+1],",",2); Bottom Group Data
			
				$CtrlPosTemp1 = ControlGetPos(HWnd($ParentGUI ),"",Number($TempX3[0]) )
				$CtrlPosTemp2 = ControlGetPos(HWnd($ParentGUI ),"",Number($TempX3[0]+1) )
				$CtrlPosTemp3 = ControlGetPos(HWnd($ParentGUI ),"",Number($TempX3[0]+2) )
				$CtrlPosTemp4 = ControlGetPos(HWnd($ParentGUI ),"",Number($TempX3[0]+3) )
			
				GUICtrlSetPos(Number($TempX3[0]) ,$CtrlPosTemp1[0] ,$CtrlPosTemp1[1] - $CtrlPosTempMM[3]); 	 	GroupLine
				GUICtrlSetPos(Number($TempX3[0]+1) ,$CtrlPosTemp2[0] ,$CtrlPosTemp2[1] - $CtrlPosTempMM[3]); 	Button
				GUICtrlSetPos(Number($TempX3[0]+2) ,$CtrlPosTemp3[0] ,$CtrlPosTemp3[1] - $CtrlPosTempMM[3]); 	Paper
				GUICtrlSetPos(Number($TempX3[0]+3) ,$CtrlPosTemp4[0] ,$CtrlPosTemp4[1] - $CtrlPosTempMM[3]); 	Label
				
				$Temp4 = StringSplit($TempX3[4],"*")
				For $IZ = 1 To $Temp4[0]-1
					$CtrlPosTemp = ControlGetPos(HWnd($ParentGUI ),"",Number($Temp4[$IZ]) )
					GUICtrlSetPos(Number($Temp4[$IZ]) ,$CtrlPosTemp[0] ,$CtrlPosTemp[1] - $CtrlPosTempMM[3])
					$CtrlPosTemp = ControlGetPos(HWnd($ParentGUI ),"",Number($Temp4[$IZ]+1) )
					GUICtrlSetPos(Number($Temp4[$IZ]+1) ,$CtrlPosTemp[0] ,$CtrlPosTemp[1] - $CtrlPosTempMM[3])
				Next
			Next
		EndIf
		;---------------Check to Set the right type of arrow Image
		$Temp1 = StringSplit(GUICtrlRead($CtrlIdOfOn-1),"|")
		$Temp2 = ControlGetPos(HWnd($PageMenuUDF_FullData[$Temp1[1]][1]),"",Number($CtrlIdOfOn+1))
		If $Temp2[3] = 1 Then
			GUICtrlSetImage ( $CtrlIdOfOn, $PageMenuUDF_FullData[$Temp1[1]][8])
		Else
			GUICtrlSetImage ( $CtrlIdOfOn, $PageMenuUDF_FullData[$Temp1[1]][5])
		EndIf
		;---------------Check to Set the right type of arrow Image
	EndIf
EndFunc   ;==> PageMenuOnButtonUp


Func PageMenuOnButtonDown($CtrlIdOfOn)
	$Temp1 = StringSplit(GUICtrlRead($CtrlIdOfOn-1),"|")
	$Temp2 = ControlGetPos(HWnd($PageMenuUDF_FullData[$Temp1[1]][1]),"",Number($CtrlIdOfOn+1))
	If $Temp2[3] = 1 Then
		GUICtrlSetImage (  $CtrlIdOfOn, $PageMenuUDF_FullData[$Temp1[1]][9])
	Else
		GUICtrlSetImage ( $CtrlIdOfOn, $PageMenuUDF_FullData[$Temp1[1]][6])
	EndIf
	;-------------------------------------------
	$PGMENPressedGroup = 1
EndFunc   ;==> PageMenuOnButtonDown